# Downloads-Installs-GAM7
You can download and install the current GAM7 release from the [GitHub Releases](https://github.com/GAM-team/GAM/releases/latest) page.
Choose one of the following:

## Executable, Automatic

* Executable Archive, Automatic, Linux/Mac OS/Google Cloud Shell/Raspberry Pi/ChromeOS
  - Start a terminal session and execute one of the following commands:
  - New install, default path `$HOME/bin`
    - `bash <(curl -s -S -L https://git.io/gam-install)`
  - New install, specify a path
    - `bash <(curl -s -S -L https://git.io/gam-install) -d <Path>`
  - Update to latest version, do not create project or authorizations, default path `$HOME/bin`
    - `bash <(curl -s -S -L https://git.io/gam-install) -l`
  - Update to latest version, do not create project or authorizations, specify a path
    - `bash <(curl -s -S -L https://git.io/gam-install) -l -d <Path>`

By default, a folder, `gam7`, is created in the default or specified path and the files are downloaded into that folder.
Add the `-s` option to the end of the above commands to suppress creating the `gam7` folder; the files are downloaded directly into the default or specified path.

If, when executing one of the above commands, you get an error message stating that Python is not installed,
go here [Python](https://www.python.org/downloads/) and download/install Python. When the installation is complete,
start a new terminal session and reissue the command from above.

## Executable, Manual

* Executable Archive, Manual, Linux/Google Cloud Shell
  - `gam-7.wx.yz-linux-x86_64-glibc2.35.tar.xz`
  - `gam-7.wx.yz-linux-x86_64-glibc2.39.tar.xz`
  - `gam-7.wx.yz-linux-x86_64-legacy.tar.xz`
  - Download the archive, extract the contents into some directory.
  - Start a terminal session.

* Executable Archive, Manual, Raspberry Pi/ChromeOS ARM devices
  - `gam-7.wx.yz-linux-arm64-glibc2.35.tar.xz`
  - `gam-7.wx.yz-linux-arm64-glibc2.39.tar.xz`
  - `gam-7.wx.yz-linux-arm64-legacy.tar.xz`
  - Download the archive, extract the contents into some directory.
  - Start a terminal session.

* Executable Archive, Manual, Mac OS versions Sonoma, Sequoia - M1/M2
  - `gam-7.wx.yz-macos14.7-arm64.tar.xz`
  - Download the archive, extract the contents into some directory.
  - Start a terminal session.

* Executable Archive, Manual, Mac OS versions Sequoia - M3
  - `gam-7.wx.yz-macos15.4-arm64.tar.xz`
  - Download the archive, extract the contents into some directory.
  - Start a terminal session.

* Executable Archive, Manual, Mac OS, versions Ventura, Sonoma, Sequoia - Intel
  - `gam-7.wx.yz-macos13.7-x86_64.tar.xz`
  - Download the archive, extract the contents into some directory.
  - Start a terminal session.

* Executable Archive, Manual, Windows 64 bit
  - `gam-7.wx.yz-windows-x86_64.zip`
  - Download the archive, extract the contents into some directory.
  - Start a Command Prompt/PowerShell session.

* Executable Installer, Manual, Windows 64 bit
  - `gam-7.wx.yz-windows-x86_64.msi`
  - Download the installer and run it.
  - Start a Command Prompt/PowerShell session.

* Executable Archive, Manual, Windows 11 ARM
  - `gam-7.wx.yz-windows-arm64.zip`
  - Download the archive, extract the contents into some directory.
  - Start a Command Prompt/PowerShell session.

* Executable Installer, Manual, Windows 11 ARM
  - `gam-7.wx.yz-windows-arm64.msi`
  - Download the installer and run it.
  - Start a Command Prompt/PowerShell session.

## Source

* Source, all platforms
  - `Source code(zip)`
  - `Source code(tar.gz)`
  - Download the archive, extract the contents into some directory.
  - Start a terminal/Command Prompt/PowerShell session.
